@@ -21,10 +21,18 @@ G_BEGIN_DECLS
 /* VOID:BOXED (./gstmarshal.list:5) */
 #define gst_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
 
-/* VOID:POINTER (./gstmarshal.list:6) */
+/* VOID:BOXED,OBJECT (./gstmarshal.list:6) */
+extern void gst_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
+                                            GValue       *return_value,
+                                            guint         n_param_values,
+                                            const GValue *param_values,
+                                            gpointer      invocation_hint,
+                                            gpointer      marshal_data);
+
+/* VOID:POINTER (./gstmarshal.list:7) */
 #define gst_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:POINTER,OBJECT (./gstmarshal.list:7) */
+/* VOID:POINTER,OBJECT (./gstmarshal.list:8) */
 extern void gst_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -32,10 +40,10 @@ extern void gst_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT (./gstmarshal.list:8) */
+/* VOID:OBJECT (./gstmarshal.list:9) */
 #define gst_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
-/* VOID:OBJECT,PARAM (./gstmarshal.list:9) */
+/* VOID:OBJECT,PARAM (./gstmarshal.list:10) */
 extern void gst_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -43,7 +51,7 @@ extern void gst_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:OBJECT,POINTER (./gstmarshal.list:10) */
+/* VOID:OBJECT,POINTER (./gstmarshal.list:11) */
 extern void gst_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -51,7 +59,7 @@ extern void gst_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT,BOXED (./gstmarshal.list:11) */
+/* VOID:OBJECT,BOXED (./gstmarshal.list:12) */
 extern void gst_marshal_VOID__OBJECT_BOXED (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -59,7 +67,7 @@ extern void gst_marshal_VOID__OBJECT_BOXED (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:OBJECT,BOXED,STRING (./gstmarshal.list:12) */
+/* VOID:OBJECT,BOXED,STRING (./gstmarshal.list:13) */
 extern void gst_marshal_VOID__OBJECT_BOXED_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -67,7 +75,7 @@ extern void gst_marshal_VOID__OBJECT_BOXED_STRING (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT,STRING (./gstmarshal.list:13) */
+/* VOID:OBJECT,OBJECT,STRING (./gstmarshal.list:14) */
 extern void gst_marshal_VOID__OBJECT_OBJECT_STRING (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -75,7 +83,7 @@ extern void gst_marshal_VOID__OBJECT_OBJECT_STRING (GClosure     *closure,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);
 
-/* VOID:OBJECT,STRING (./gstmarshal.list:14) */
+/* VOID:OBJECT,STRING (./gstmarshal.list:15) */
 extern void gst_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -83,7 +91,7 @@ extern void gst_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:INT,INT (./gstmarshal.list:15) */
+/* VOID:INT,INT (./gstmarshal.list:16) */
 extern void gst_marshal_VOID__INT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -91,7 +99,7 @@ extern void gst_marshal_VOID__INT_INT (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* VOID:INT64 (./gstmarshal.list:16) */
+/* VOID:INT64 (./gstmarshal.list:17) */
 extern void gst_marshal_VOID__INT64 (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -99,7 +107,7 @@ extern void gst_marshal_VOID__INT64 (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
-/* VOID:UINT,BOXED (./gstmarshal.list:17) */
+/* VOID:UINT,BOXED (./gstmarshal.list:18) */
 extern void gst_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -107,10 +115,10 @@ extern void gst_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:UINT,POINTER (./gstmarshal.list:18) */
+/* VOID:UINT,POINTER (./gstmarshal.list:19) */
 #define gst_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER
 
-/* BOOLEAN:VOID (./gstmarshal.list:19) */
+/* BOOLEAN:VOID (./gstmarshal.list:20) */
 extern void gst_marshal_BOOLEAN__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -118,7 +126,7 @@ extern void gst_marshal_BOOLEAN__VOID (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* BOOLEAN:POINTER (./gstmarshal.list:20) */
+/* BOOLEAN:POINTER (./gstmarshal.list:21) */
 extern void gst_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -126,7 +134,7 @@ extern void gst_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* POINTER:POINTER (./gstmarshal.list:21) */
+/* POINTER:POINTER (./gstmarshal.list:22) */
 extern void gst_marshal_POINTER__POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -134,7 +142,7 @@ extern void gst_marshal_POINTER__POINTER (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* BOXED:BOXED (./gstmarshal.list:22) */
+/* BOXED:BOXED (./gstmarshal.list:23) */
 extern void gst_marshal_BOXED__BOXED (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
